/* =============================================================================
Economic Polarization and Antisocial Behavior: An Experiment
Bigoni, Bortolotti & Nas Ozen                                                                                       
                                                                                
credits:                                                                        
- Kan  Takeuchi for the ztree2stata ado file: https://sites.google.com/view/takekan/research/ztree2stata
  (ado file available for download online and in this folder)                                  
- Stata FAQ: How can I combine a large number of files?                         
  UCLA: Academic Technology Services, Statistical Consulting Group.             
  from http://www.ats.ucla.edu/stat/stata/faq/append_many_files.htm             
  (accessed October 3, 2012).                                                   
===============================================================================*/

* NOTE: be sure to run this file in the folder containing an "origianls" folder where you have stored the .xls files     
* produced by ztree (and nothing else)                                                                                   
*************************************************************************************************************************
* 0. Set directory
cd ""

clear
set more off

* 1. create a folder where to store the dataset
capture mkdir data

* 2. check if ztree2stata is already installed, and install it if it is not
capture which ztree2stata

* 3. move to the directory when you have the original .xls files produced by zTree
cd ./originals

* 4. create a text file containing the list of all the xls files produced by zTree
* for windows
*capture ! dir *.xls /a-d /b >../filelist.txt
*for macOS
capture ! ls *.xls >list.txt

* 5. open this text file
cap file close LIST
file open LIST using list.txt, read

* 6. delete previously existing data file
cap rm ../data/raw_data_BELIEFS.dta
cap rm raw_data_BELIEFS.dta

* 7. import the data 
file read LIST filename
while r(eof)==0 { /* while you're not at the end of the file */
	ztree2stata subjects using "./`filename'", save clear replace
	preserve
		*keep if treatment==2
		keep if treatment==3
		tempfile questionnaire
		keep session Subject age-right
		save `questionnaire', replace
	restore
	merge m:1 session Subject using "`questionnaire'", update replace
	drop _merge
	preserve
		ztree2stata globals using "./`filename'", save clear replace except(treatment)
		keep if treatment==1
		tempfile globals
		keep session sequential
		sum
		save `globals', replace
	restore
	merge m:1 session using "`globals'", update replace
	drop _merge
	preserve
		keep if treatment==1
		tempfile task
		keep Subject session guess1 guess2 payoff_total rightanswersCQpart1 rightanswersCQpart2 WrongAnswers*
		save `task', replace
	restore
	merge m:1 session Subject using "`task'"
	drop _merge
	drop if treatment >=2
	cap append using raw_data_BELIEFS
	save raw_data_BELIEFS, replace
	file read LIST filename
}
file close LIST

cap rm list.txt 


* 8. number the first session, and calculate the date of that session
encode(session), gen(s)
replace session=subinstr(session,"_"," ",1)
replace session=string(20)+session
generate date = clock(session , "YMDhm")
format date %tc
drop session
rename s session

* gen number of mistakes
egen Mistakes = rowtotal (WrongAnswers*)


* 9 clean and organize the dataset
	
keep date session sequential Subject guess1 guess2 RightAnswers Mistakes payoff_total age male field country right 

label variable guess1 "Share of RIGHT"
label variable guess2 "Share of UP"

label define sequential 1 "Sequential" 0 "Simultaneous", modify
label values sequential sequential

label define field 1 "social sciences" 2 "math sciences" 3 "engineering/architecture" 4 "medicine" 5 "arts/humanities" 6 "other" 7 "not a uni student", modify
label values field field

label define country 1 "Italy" 2 "other EU" 3 "non-EU Europe, Russia" 4 "Middle East" 5 "China" 7 "India" 8 "USA" 9 "other"
label values country country

label define male 1 "Male" 0 "Female", modify
label values male male

* one leaf was open by mistake and advanced by the experimenter
drop if session==3 & Subject==4

* one subject refused to answer the question on political orientations and a random value has been entered
replace right=. if session==4 & Subject==16
	
sort date session Subject

****

* 10. save the dataset in the "data" folder and remove the .dta file automatically generated by ztree2stata
saveold ../data/raw_data_BELIEFS, replace

* 11. delete the files that are not needed anymore
*capture !dir ../originals/1*.dta /a-d /b > list.txt //for windows
capture !ls ../originals/1*.dta > list.txt //for mac

cap file close LIST

file open LIST using list.txt, read

file read LIST filename

while r(eof)==0 { /* while you're not at the end of the file */
	rm "`filename'"
	file read LIST filename
}
file close LIST

cap rm raw_data_BELIEFS.dta

rm list.txt

cd ..



