/* =============================================================================
Economic Polarization and Antisocial Behavior: An Experiment
Bigoni, Bortolotti & Nas Ozen                                                             
                                                                                
credits:                                                                        
- Kan  Takeuchi for the ztree2stata ado file: https://sites.google.com/view/takekan/research/ztree2stata
  (ado file available for download online and in this folder                                 
- Stata FAQ: How can I combine a large number of files?                         
  UCLA: Academic Technology Services, Statistical Consulting Group.             
  from http://www.ats.ucla.edu/stat/stata/faq/append_many_files.htm             
  (accessed October 3, 2012).                                                   
===============================================================================*/

* NOTE: be sure to run this file in the folder containing an "origianls" folder where you have stored the .xls files     
* produced by ztree (and nothing else)                                                                                   
*************************************************************************************************************************
* 0. Set directory

cd ""

clear
set more off

* 1. create a folder where to store the dataset
capture mkdir data

* 2. check if ztree2stata is already installed, and install it if it is not
capture which ztree2stata

* 3. move to the directory when you have the original .xls files produced by zTree
cd ./originals

* 4. create a text file containing the list of all the xls files produced by zTree
* for windows
*capture ! dir *.xls /a-d /b >../filelist.txt
*for macOS
capture ! ls *.xls >list.txt

* 5. open this text file
cap file close LIST
file open LIST using list.txt, read

* 6. delete previously existing data file
cap rm ../data/raw_data_MAIN.dta
cap rm raw_data_MAIN.dta

* 7. import the data 
file read LIST filename
while r(eof)==0 { /* while you're not at the end of the file */
	ztree2stata subjects using "./`filename'", save clear replace
	preserve
		keep if male<2
		tempfile questionnaire
		keep session Subject age-hex60
		sum
		save `questionnaire', replace
	restore
	merge m:1 session Subject using "`questionnaire'", update replace
	drop _merge
	preserve
		ztree2stata session using "./`filename'", save clear replace except(treatment)
		keep if treatment>3
		tempfile session
		sort session treatment Subject
		keep session Subject FinalProfit rightanswersCQ* payoffCQ* condition order exit_option
		save `session', replace
	restore
	merge m:1 session Subject using "`session'"
	drop _merge
	preserve
		keep if ResponseTime1 < .
		keep Subject session treatment Wrong* Response*
		egen wronganswers=rowtotal(Wrong*)
		egen responsetime=rowtotal(Response*)
		keep session Subject treatment wrong response
		reshape wide wrong response, j(treatment) i(Subject session)
		egen wronganswers=rowtotal(wrong*)
		egen responsetime=rowtotal(response*)
		tempfile quiz
		save `quiz', replace
	restore
	merge m:1 session Subject using "`quiz'"
	drop _merge
	preserve
		keep if treatment==1
		tempfile task
		keep Subject session Correct_task Wrong_task correct_group 
		save `task', replace
	restore
	merge m:1 session Subject using "`task'"
	drop _merge
	drop if inlist(treatment,1,4,5)
	cap append using data
	save data, replace
	file read LIST filename
}
file close LIST

cap rm list.txt 

* 8. number the first session, and calculate the date of that session
encode(session), gen(s)
replace session=subinstr(session,"_"," ",1)
replace session=string(20)+session
generate date = clock(session , "YMDhm")
format date %tc
drop session
rename s session
gen Phase=treatment-1 
drop if Period==6
gen tot_period=Period
replace tot_period=Period+5 if Phase==2


* 9 clean and organize the dataset
	
keep Subject Group Color Period Phase tot_period partner pay_round payoffTeamTask partnerchoice partnerexit exit profit profit_partner ///
	profit_p* sum_profit* sum_exit wronganswers responsetime session date ///
	FinalProfit condition order exit_option age male field country right choice* hex* matched_set
	

order date session condition Subject Group Color Period Phase tot_period choice* profit exit ///
	partner matched_set partnerchoice partnerexit profit_partner profit_p* sum_profit* sum_exit  ///
	pay_round FinalProfit payoffTeamTask wronganswers responsetime age male field country right hex*
	
sort date session Subject


label define Color 1 "red" 2 "blue", modify
label values Color Color

label define field 1 "social sciences" 2 "math sciences" 3 "engineering/architecture" 4 "medicine" 5 "arts/humanities" 6 "other" 7 "not a uni student", modify
label values field field

label define country 1 "Germany" 2 "other EU" 3 "non-EU Europe, Russia" 4 "Middle East" 5 "China" 7 "India" 8 "USA" 9 "other"
label values country country

label define male 1 "Male" 0 "Female", modify
label values male male

foreach var of varlist choice{
	replace `var'=`var'+2 if Color==2 & choice!=-1
}

foreach var of varlist partnerchoice{
	replace `var'=`var'+2 if Color==1 & partnerchoice!=-1
}


label define choice 0 "down" 1 "up" 2 "right" 3 "left", modify

replace choice_r=. if choice_r==-1
label define choice_r 0 "down" 1 "up", modify

replace choice_l=. if choice_l==-1
label define choice_l 0 "down" 1 "up", modify


foreach var of varlist *choice*{
	label values `var' choice
}


* 10. save the dataset in the "data" folder and remove the .dta file automatically generated by ztree2stata
saveold ../data/raw_data_MAIN, replace

* 11. delete the files that are not needed anymore
*capture !dir ../originals/1*.dta /a-d /b > list.txt //for windows
capture !ls ../originals/1*.dta > list.txt //for mac

cap file close LIST

file open LIST using list.txt, read

file read LIST filename

while r(eof)==0 { /* while you're not at the end of the file */
	rm "`filename'"
	file read LIST filename
}
file close LIST

cap rm raw_data_MAIN.dta

rm list.txt

cd ..

*----------------------------------------*
*     to generate the data_Main.dta      *
*----------------------------------------*
* keep session Subject Color Period Phase tot_period choice choice_r choice_l profit exit matched_sets partnerchoice wronganswers age male field country right order exit_option 
* order session Subject Color Period Phase tot_period choice choice_r choice_l profit exit matched_sets partnerchoice wronganswers age male field country right order exit_option  

